/* ###*B*###
 * ERIKA Enterprise - a tiny RTOS for small microcontrollers
 *
 * Copyright (C) 2002-2010  Evidence Srl
 *
 * This file is part of ERIKA Enterprise.
 *
 * ERIKA Enterprise is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation, 
 * (with a special exception described below).
 *
 * Linking this code statically or dynamically with other modules is
 * making a combined work based on this code.  Thus, the terms and
 * conditions of the GNU General Public License cover the whole
 * combination.
 *
 * As a special exception, the copyright holders of this library give you
 * permission to link this code with independent modules to produce an
 * executable, regardless of the license terms of these independent
 * modules, and to copy and distribute the resulting executable under
 * terms of your choice, provided that you also meet, for each linked
 * independent module, the terms and conditions of the license of that
 * module.  An independent module is a module which is not derived from
 * or based on this library.  If you modify this code, you may extend
 * this exception to your version of the code, but you are not
 * obligated to do so.  If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * ERIKA Enterprise is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License version 2 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * version 2 along with ERIKA Enterprise; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 * ###*E*### */

/*
 * Author: 2014,  Francesco Esposito
 * Company: Evidence SRL
 */

#ifndef EE_MCU_MPC5643L_INITHW_H
#define EE_MCU_MPC5643L_INITHW_H

#include <cpu/common/inc/ee_stdint.h>
#include <mcu/freescale_mpc5643l/inc/MPC5643L.h>

/* To include configuration parameters generated by RT-Druid */
#include "eecfg.h"

/* CPU_CONFIG reppresents the current system configuration */
#if defined (__MSRP__)
/* Dual core case */
#if defined (__E200ZX_EXECUTE_FROM_RAM__)
#define CPU_CONFIG 0x4U /* Dual core loaded in RAM */
#else
#define CPU_CONFIG 0x5U /* Dual core loaded in Flash */
#endif  /* defined (__E200ZX_EXECUTE_FROM_RAM__) */

#else
/* Single core case (Lock-step or DPM) */
#if defined (__E200ZX_EXECUTE_FROM_RAM__) && !defined (LOCK_STEP)
#define CPU_CONFIG 0x6U /* single core, no lockstep, loaded in RAM. */
#elif !defined (__E200ZX_EXECUTE_FROM_RAM__) && !defined (LOCK_STEP)
#define CPU_CONFIG 0x1U /* single core, no lockstep, loaded in Flash. */
#elif !defined (__E200ZX_EXECUTE_FROM_RAM__) && defined (LOCK_STEP)
#define CPU_CONFIG 0x2U /* single core in lockstep, loaded in Flash. */
#elif defined (__E200ZX_EXECUTE_FROM_RAM__) && defined (LOCK_STEP)
#define CPU_CONFIG 0x3U /* single core in lockstep, loaded in RAM. */
#else
#warning "Illegal system configuration!"
#endif  /* defined (__E200ZX_EXECUTE_FROM_RAM__) && !defined (LOCK_STEP) */

#endif  /* defined (__MSRP__) */

#define FCCU_NCFK_KEY 0xAB3498FE
#define FCCU_CFK_KEY  0x618B7A50

void InitHW(void);
void InitSysclk(void);
void InitGPIO(void);
void DisableWatchdog(void);
void InitModesAndClks(void);
void InitPeriClkGen(void);
void ClearFails(void);
void InitSTM(void);
void TestPWMOutput(void);

#endif
